/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvControlIf.h"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvSignalEnvelope.h"
#include "HvControlDelay.h"
#include "HvControlBinop.h"
#include "HvSignalLine.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_7JQv1du6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6BQRYsCP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fGelnqGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TpZOLF2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cQZYry99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cz2ZRdCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9AmRg3Ee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2S5qWhT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lFCq2RZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nlFBWHDG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2f4w1GQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lmEgpezY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0yubj265_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_762OaX1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_azc80sQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CXnXLxuk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rhBqkRAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ITjzpUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4gXbGdu2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uCZYmwuY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aO6mXF1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XTl26tdk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_bazcJGxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lPMxG0I1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hYiBycDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bUZBo1MH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_14vMpxc5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4bhhMZ8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iYr72Pkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Nc40jQQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xrZeyfG8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_skmvLwHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PQ4lJI40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_olNIAnJA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3vvFmeul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_faGIyA3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JqhG9Vzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YFIkpubQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jWYKU7Nh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Nqg1sFB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X6r6jsVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ofS84xs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_r9aIvHUZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ya2T9MrT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5G4Men85_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ikX2ZlzB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f8eercvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_abiu7Z3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M7Tb6T19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aoeDb7lh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zRz9Xtrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uZ944S2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LGckCJRJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LBUCLgcZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3MnnLvgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yx8AbdVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GODJ4QD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HkwBdGA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bXvBn1ON_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_PfwUpue9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x4nmPEm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4dkywCpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CnUKrkrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EAohF3nX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4EM92KLx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9uhFMDwa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3JGEKIsF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RPnnc8k3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L0lbIhzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lLcxLSOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_u0qYzRtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_j9RvSHtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sHsV08wN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_QDq6Za7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2dkft3N5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ykAZMh7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TKt5AOF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ppctZRx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CGKVt8jR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yq3PgNT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UaJju0sm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8gSYj0i2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QCvsAizq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6jRrkdtx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SBn4boLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_e6nfrpYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mi2G8wRp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_yuOS3ObS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TxZY1X2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GK9YcLyi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TWiFT9OQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TyTzMgw5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XdtUlkq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_41oJAksR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xx3NDhzJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lYYnvo7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_adirKwR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cBalV1kV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IvlMdM7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7Nj7qeDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WdfokZ8t_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_xmHlM4xh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3aRuivRK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OJDiSrH7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ocgjJlKV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hBQ7UlCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jQhirGAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a9PGw6hq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iY3taDYg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2diXqyjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZHPP3u2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kgTa3AcS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bXSHrEVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_15I0XmjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Gz1AgyDL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Wfiwpdgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aICiPseX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YTTDIPTs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nmpdst3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6z73nGpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SnIPXpo8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mhDc5CMt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZZdBmab6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ZtmSP84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BL9zvKBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_16Lb8A0E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tr8PtH7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IBCwvfBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_a3sF2irK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_aGnfXdBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lPi8EiT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iT1Q8Im1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YYhpt16t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i9N7tFc5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TczP8Ql1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6n1AcyfV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B0kfJBuY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WW90gvbq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aKjqXcdD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0uKihDC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1QrfwbRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_k9KX7bor_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iwbOYo4e_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_vZ1oB6uW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P22I5ffT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OhbZ7r0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X5QpsEVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cU8EiNOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XJBP76cM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1PlztDSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SrPLRqUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TYNJ4unl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_92x1jISI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ivivsd6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ERtBMAkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5eJWVdFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WZ6vmwDy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_WlSusi5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kDJ4BcGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YEgwjJjd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gVgQ9Xrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pr8xdGnj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2oeWg6Mi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AWROS5NJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IxaXcYUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fKJmqzRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aXMXG5tW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MSMuIXpz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WFACJoV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2OaJrHoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_73P8Gboz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_LL8O6MzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_710N6Nca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WMlivmZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w2WBc08P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OuKKMCA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LWXJ85zo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MyKTBVnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wlx0ycdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wC0ig0jR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bFhfi6dp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E5sPrmK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lUMZ68Rl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MQdikn15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_E9nMdqzS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_iNmx2BhP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mgfupNId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iLX1Gh61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YcfAd8rw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AizZFk32_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cjcDmMY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9yRfA8ry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NzfBpZwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ORVMsyA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jMyxC3JP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WpHP0s7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2gZNNEd4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vadhuTFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0rLbquXE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pI856j18_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8DkY0JS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cGBDY0aQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xNI2wtIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JYXv2oVD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jqYQBbiV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k8uEXcL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_24HX6ptG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l56FnBzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fREJzH3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fKb3DhFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_amHIreOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JCAUMN2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FbNNFCad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ERyINhpB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rdJE4VnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qby20v9f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9BbxcshO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xoErCpzT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_11x3eno5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QVDaw4wA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C6yRGsXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IcJeKxGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9r1s5L8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0CaWCpRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xDUhc97p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aixDt6rh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7inBnPHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xnOuiyu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KKTZQEii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_inqkBf1f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qITCV7mn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_17k0jcoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3DCZ9tQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R29f8ZzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d8rGzi34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dnfenZSx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lkCEiASL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QWhzIAtD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UtujnAn1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rLu3NZJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wXB3ObEs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pHi6BPiH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_R7NJzqH1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2ivQmAM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hp2XObpV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XxVpAX1j_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_cQrKn7nz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rAHckH8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bHAJWYwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hyMPpD0X_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_YYS0IrJo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SplAAonJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_i9pAml96_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tRNRtnV1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_tp9YZB6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pvXWuLGm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fz1KQbxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HVE9GpQG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9YRLzpYj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8E3LIhgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6QKB0EAa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_idIatUoD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_8tcChfHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wj80bL2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qna0L5v4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xoIfLDeC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qgcxQfL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Bt9R4UR0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_e56GlJo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_VwAPW3Gb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bxLOiIxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jNB0beuA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2SPpjU0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_prKJJX3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2w8aNEwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eQBEH3H4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kz64Mzjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zcn4POEh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qs9FzviJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nVwkdUjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zag42cvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FUdR1jHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g5rWUKmW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9MdKNKFO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_SrhOi9rp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_00zUYIUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wO3VICnK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b3usDJux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M7GIz93X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Io1tSZpc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aWlhwHH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3UXf5GzU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yyeATnWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0n0klmB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nwrj4KyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lL78mAUN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o7TdgUIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gsTMme3s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yVWmBeJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rAmdhNOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FOMLuUyd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_vgfSOgBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B6g6wlIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tuP7HHnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vARB6Jyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_08gfhtia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tOdBnuEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EIW7Zzfe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yqPEVnbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bh33jITe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_301qgHag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WsGMeVb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4OZTTxmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YgaKX6JP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8HmlL5yP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8qQ69YcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DT1vQoxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iCNaTdNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6G8O57gH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nJObUSxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LwLCWpoc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_D6r2EpmY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DLtqFPsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_J6LI0ReY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_HoQq5N9I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HIvqqgng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dvUO0rWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wc2pSUcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cU1s8oO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TN77PaHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S6ieCX2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jAxItjb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_waRk8f44_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KWW0RGc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_awOaC6bb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XaEtaaZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ryY2smPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tdJ02S6T_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_PmWi4n1a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1ywERTDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wT8oaI1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_II5xuY53_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UrOKX4G8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9Le1eZxS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hBDmSqTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vPbNAzVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iXMbrPd4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wpftzEvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wSlfr8YA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_V2UT4hxy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Y8SIrEKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9I0yzIhZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_9zmooo9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1bfbzEPQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2tLjr39P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YOBraqYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VQEZiUGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vpOTZTtN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kZOXDfph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YMCnzHMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QymySCoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uOkzigdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ujrL3SCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wNd2A3II_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nZukfFGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fDDJJEXX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Dm4WV4x6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WxxCqGQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K7cDvZ5T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hv8FbS3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZjNRDsgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m6PyxyuQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_umWkxpBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hCKkiDsc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3t7zuXeM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KXpOtF5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0IWMqPNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yDxxXTUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wBEO8yrB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_deissGp6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_oqYN3MK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r9Q8BVel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8pt2i4dr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QR9o9Hbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q5mNASjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dy18FyQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OvTX2op7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_azE1lRMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DOQ0DMFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AbtYfQyn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V15eqFAj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2PxQ1Abu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SdpCOTnw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mRizZxfN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_b7DJI0BF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ruu4K1xD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2XTVuEwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BPGhF2Io_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q1fsWXkt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zz1lhom4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rQmxTBGe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t6XzQVzG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GOqL1VJE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0lDwEbH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HWxQPG7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SxqHKOtk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5qbnhLUC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qTub78fD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_yINUTumI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VnnxixUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k2TtRSml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_75nfu1n4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ojx8MO15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AMJPjHvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5xjZpFgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hz5W5zx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EN5lZnFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RJizaH24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TFsgRuUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HiaZZKlf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PWMxvvnV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WOqGrwMr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lrPVhDDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oKcf7ZYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_suCIzbIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t9jg2vk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ftF9f5ps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WPVDdepT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D1ZuHglb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x9teX6bq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zQJxVljX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cYhOSfmG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sgsZWGzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2MGmAg4I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eO5alinQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xtCjgPvC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_pi1plrVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5iaF8oAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sUUxaeE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VQXRkjoK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_phzc9jBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PYF2Xvjj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YVy574L1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z60X6onH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lb2nNcdi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xfjEqWFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eEcpJAHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pCT6yQKb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7ow8wkio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_D9wv3iCt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_N6jFF4je_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ly7WiwPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VSGNQ01U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_auyoWr1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sBR4VQDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mxRVRnDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aduIA298_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xuinAWgm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CVsTMay4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_06BQDFRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3d8SK6Rg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EtDIV13K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UoJmAPt6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_w0ZuQWi6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dA78cskv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x0qaZCLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R9kqkpvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pa8qYplT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vy2dy8K6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1PKjA1Ah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8HwBvoRD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LxDcNo9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x8AnlrvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6hN2kL2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gLXEKLFS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Mny0HwDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m8P3IFfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lR8roPiq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qp2j3Erg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w3RU5N2D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gP44pU10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9nHXkom5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Eozbbgvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T5IiOnSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vhh6YyaG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M5hPODDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r5ffBfw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UWJnkMDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gegn6sf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RQnuMe52_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M1TaECeB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d30znDzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UvdJaXkO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Decpt5cH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LiB3EE93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ecaAxu95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1K9Kigmy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ao63S0ko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DTnIMRqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oeRzk8YN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EpN9bpYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bXwCzMdZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ae7eFhpp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LFTR8dPA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6fnRN1Ep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XDuAGMmz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rop1urwr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R84YpPK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jst82ZkH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vs6pih2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CAwKOdc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_icl8EmaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6xIgVBTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3PhYwgay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ja9CqBd3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pvXf87IU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sYvHFjrd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HVXxKwK8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YbySwaTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s49tb9Gz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CyrANxZA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XonhxjVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_guqXgR6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_i97CgUcv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rrKfULrt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GVc74ro7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hV1NkMqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xLGS6OPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_pOa2oyzn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_WDSjIx7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uXEJR3Fd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5VV0KldO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vq2OoRVv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_2fXJZIBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lJK50tUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6QuFgl2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5gAUG0Ww_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_WVPWGkln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ypo3mK9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cANDXHLe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tmEclVhB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_VC5wicFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GOCq1bcO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XDSXmLMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y4CPznaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_drm4eO7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JZQ87MBa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_ahZGbell_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_3kPndpho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3JKJ0DOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zzFbmgwc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RGeDf6jk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_evE5ndeQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UycYiFYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xk7Acg42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xZLFAYmZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oMKGBLz5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qW97Vcn3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cyb9bYvR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CLovvLvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7r1b3kC5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_89HdGs8o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iBFwdca6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_fzobyjvL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QznjXeA5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_w8S9Nfat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xKcy7jLI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gNYE3rAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Psa86rZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vel3p3AZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EgCMiQMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NwUxXTjI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A1d60PoZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g3eSq71z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TJ6WsnTI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z05kIrzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fYotLIXD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wFvqfChy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J6raJGWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a2VzWsrR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_KeQ9cpHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HSHGEekV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QfODRbU9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_85OjOAZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_99D1GOgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCcdI6tu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XL6IamBH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aexdeCJA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v7fd5re8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t4pZ68zC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mj2X4sCR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HtK5okA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Riy2AEtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o2AKfTjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DZeZNVK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sQXIvQXD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zYNWgLqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Unwajoxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xyfKsSS9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VbSxYKvE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xczmOinX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kh742vqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uiYdpQlh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YznSQQJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cu8P33fD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mrcpqqza_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Dnr253R3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rlvSHxsc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tU8MIyiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1kXLOZrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dUFjtQ3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PQMSY6Ek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5NCmHojW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5dIlDU5v_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_OdYFE2ZW;
  SignalLine sLine_qTLFMXVu;
  SignalLine sLine_xyZqn2W8;
  SignalLine sLine_FJWQXHBA;
  SignalLine sLine_ePaHBDLc;
  SignalLine sLine_xRHeOaag;
  SignalLine sLine_MyhzOjSR;
  SignalLine sLine_1RseGAD7;
  SignalLine sLine_rbdDuGwt;
  SignalLine sLine_9OuW3cUm;
  SignalLine sLine_57HKroR8;
  SignalLine sLine_aPlGpQMT;
  SignalEnvelope sEnv_e56GlJo6;
  SignalEnvelope sEnv_VwAPW3Gb;
  SignalLine sLine_3xVt32ck;
  SignalLine sLine_wCTiz1Db;
  SignalLine sLine_yZs5VTQ2;
  SignalLine sLine_2DDJ0GpH;
  SignalLine sLine_Sjp13NYU;
  SignalLine sLine_YOW7NTXU;
  SignalLine sLine_M9LF4GkO;
  SignalLine sLine_CvFWf12E;
  SignalLine sLine_eqN7Yqcq;
  SignalLine sLine_m7akqlsg;
  SignalLine sLine_z9c8XSaw;
  SignalLine sLine_1OofMhc1;
  SignalLine sLine_xvMFJyO9;
  SignalLine sLine_FHfZU0Ie;
  SignalLine sLine_IKjIYLLV;
  SignalLine sLine_tlKVhyUf;
  SignalLine sLine_JKzjIAoE;
  SignalLine sLine_I47n6Mnz;
  SignalEnvelope sEnv_ahZGbell;
  SignalEnvelope sEnv_3kPndpho;
  SignalLine sLine_XiS8VxwN;
  SignalLine sLine_YuJNbGwd;
  SignalLine sLine_lrgaZmrA;
  SignalLine sLine_LyMURubq;
  SignalLine sLine_eouQKh8m;
  SignalLine sLine_iP6Swx8R;
  SignalLine sLine_NdFvMSEr;
  SignalLine sLine_lbMpUuxD;
  ControlVar cVar_7JQv1du6;
  ControlBinop cBinop_6BQRYsCP;
  ControlBinop cBinop_fGelnqGB;
  ControlBinop cBinop_TpZOLF2E;
  ControlBinop cBinop_cQZYry99;
  ControlBinop cBinop_b2S5qWhT;
  ControlBinop cBinop_nlFBWHDG;
  ControlBinop cBinop_2f4w1GQD;
  ControlBinop cBinop_lmEgpezY;
  ControlVar cVar_0yubj265;
  ControlVar cVar_762OaX1y;
  ControlVar cVar_azc80sQj;
  ControlVar cVar_CXnXLxuk;
  ControlVar cVar_rhBqkRAo;
  ControlBinop cBinop_5ITjzpUR;
  ControlVar cVar_uCZYmwuY;
  ControlVar cVar_aO6mXF1l;
  ControlIf cIf_iYr72Pkh;
  ControlIf cIf_Nc40jQQe;
  ControlDelay cDelay_skmvLwHA;
  ControlBinop cBinop_3vvFmeul;
  ControlBinop cBinop_faGIyA3e;
  ControlIf cIf_r9aIvHUZ;
  ControlIf cIf_Ya2T9MrT;
  ControlDelay cDelay_ikX2ZlzB;
  ControlBinop cBinop_M7Tb6T19;
  ControlBinop cBinop_aoeDb7lh;
  ControlIf cIf_GODJ4QD4;
  ControlIf cIf_HkwBdGA7;
  ControlDelay cDelay_PfwUpue9;
  ControlBinop cBinop_CnUKrkrh;
  ControlBinop cBinop_EAohF3nX;
  ControlIf cIf_u0qYzRtV;
  ControlIf cIf_j9RvSHtg;
  ControlDelay cDelay_QDq6Za7j;
  ControlBinop cBinop_TKt5AOF2;
  ControlBinop cBinop_ppctZRx6;
  ControlIf cIf_SBn4boLP;
  ControlIf cIf_e6nfrpYs;
  ControlDelay cDelay_yuOS3ObS;
  ControlBinop cBinop_TWiFT9OQ;
  ControlBinop cBinop_TyTzMgw5;
  ControlIf cIf_IvlMdM7O;
  ControlIf cIf_7Nj7qeDk;
  ControlDelay cDelay_xmHlM4xh;
  ControlBinop cBinop_ocgjJlKV;
  ControlBinop cBinop_hBQ7UlCA;
  ControlIf cIf_bXSHrEVy;
  ControlIf cIf_15I0XmjE;
  ControlDelay cDelay_Wfiwpdgb;
  ControlBinop cBinop_Nmpdst3C;
  ControlBinop cBinop_6z73nGpX;
  ControlIf cIf_tr8PtH7O;
  ControlIf cIf_IBCwvfBk;
  ControlDelay cDelay_aGnfXdBN;
  ControlBinop cBinop_YYhpt16t;
  ControlBinop cBinop_i9N7tFc5;
  ControlIf cIf_1QrfwbRp;
  ControlIf cIf_k9KX7bor;
  ControlDelay cDelay_vZ1oB6uW;
  ControlBinop cBinop_X5QpsEVL;
  ControlBinop cBinop_cU8EiNOL;
  ControlIf cIf_ERtBMAkv;
  ControlIf cIf_5eJWVdFZ;
  ControlDelay cDelay_WlSusi5l;
  ControlBinop cBinop_gVgQ9Xrj;
  ControlBinop cBinop_pr8xdGnj;
  ControlIf cIf_WFACJoV9;
  ControlIf cIf_2OaJrHoW;
  ControlDelay cDelay_LL8O6MzO;
  ControlBinop cBinop_w2WBc08P;
  ControlBinop cBinop_OuKKMCA7;
  ControlIf cIf_lUMZ68Rl;
  ControlIf cIf_MQdikn15;
  ControlDelay cDelay_iNmx2BhP;
  ControlBinop cBinop_YcfAd8rw;
  ControlBinop cBinop_AizZFk32;
  SignalVarf sVarf_BgyxzY6l;
  SignalVarf sVarf_hYpfVyV6;
  SignalVarf sVarf_wtJLH7pl;
  SignalVarf sVarf_5ghGu2Gw;
  SignalVarf sVarf_NkW9wt3g;
  SignalVarf sVarf_JjTZtcMe;
  SignalVarf sVarf_Rtjp5K7U;
  SignalVarf sVarf_L1IxDtji;
  ControlVar cVar_wXB3ObEs;
  ControlSlice cSlice_R7NJzqH1;
  ControlVar cVar_2ivQmAM7;
  ControlSlice cSlice_cQrKn7nz;
  ControlVar cVar_rAHckH8I;
  ControlSlice cSlice_YYS0IrJo;
  ControlVar cVar_SplAAonJ;
  ControlSlice cSlice_tp9YZB6o;
  ControlVar cVar_pvXWuLGm;
  ControlSlice cSlice_9YRLzpYj;
  ControlVar cVar_8E3LIhgM;
  ControlDelay cDelay_8tcChfHu;
  ControlVar cVar_xoIfLDeC;
  ControlIf cIf_qgcxQfL5;
  ControlIf cIf_Bt9R4UR0;
  ControlBinop cBinop_bxLOiIxD;
  ControlBinop cBinop_2SPpjU0h;
  ControlBinop cBinop_prKJJX3W;
  ControlBinop cBinop_kz64Mzjq;
  ControlBinop cBinop_Qs9FzviJ;
  ControlSlice cSlice_SrhOi9rp;
  ControlVar cVar_00zUYIUP;
  SignalVarf sVarf_BoUtqCEr;
  SignalVarf sVarf_jX4bZ4ri;
  SignalVarf sVarf_0oSk3EKJ;
  SignalVarf sVarf_6X0iqXCc;
  SignalVarf sVarf_vNONVIya;
  SignalVarf sVarf_CylrREDA;
  ControlBinop cBinop_Io1tSZpc;
  ControlBinop cBinop_o7TdgUIn;
  ControlVar cVar_yVWmBeJz;
  ControlVar cVar_rAmdhNOr;
  ControlIf cIf_EIW7Zzfe;
  ControlIf cIf_yqPEVnbP;
  ControlDelay cDelay_301qgHag;
  ControlBinop cBinop_YgaKX6JP;
  ControlBinop cBinop_8HmlL5yP;
  ControlIf cIf_D6r2EpmY;
  ControlIf cIf_DLtqFPsH;
  ControlDelay cDelay_HoQq5N9I;
  ControlBinop cBinop_wc2pSUcT;
  ControlBinop cBinop_cU1s8oO0;
  ControlIf cIf_XaEtaaZw;
  ControlIf cIf_ryY2smPG;
  ControlDelay cDelay_PmWi4n1a;
  ControlBinop cBinop_II5xuY53;
  ControlBinop cBinop_UrOKX4G8;
  ControlIf cIf_V2UT4hxy;
  ControlIf cIf_Y8SIrEKg;
  ControlDelay cDelay_9zmooo9j;
  ControlBinop cBinop_YOBraqYT;
  ControlBinop cBinop_VQEZiUGz;
  ControlIf cIf_wNd2A3II;
  ControlIf cIf_nZukfFGb;
  ControlDelay cDelay_Dm4WV4x6;
  ControlBinop cBinop_hv8FbS3z;
  ControlBinop cBinop_ZjNRDsgp;
  ControlIf cIf_yDxxXTUA;
  ControlIf cIf_wBEO8yrB;
  ControlDelay cDelay_oqYN3MK0;
  ControlBinop cBinop_QR9o9Hbv;
  ControlBinop cBinop_q5mNASjn;
  ControlIf cIf_2PxQ1Abu;
  ControlIf cIf_SdpCOTnw;
  ControlDelay cDelay_b7DJI0BF;
  ControlBinop cBinop_BPGhF2Io;
  ControlBinop cBinop_Q1fsWXkt;
  ControlIf cIf_SxqHKOtk;
  ControlIf cIf_5qbnhLUC;
  ControlDelay cDelay_yINUTumI;
  ControlBinop cBinop_75nfu1n4;
  ControlBinop cBinop_Ojx8MO15;
  ControlIf cIf_HiaZZKlf;
  ControlIf cIf_PWMxvvnV;
  ControlDelay cDelay_lrPVhDDa;
  ControlBinop cBinop_t9jg2vk5;
  ControlBinop cBinop_ftF9f5ps;
  ControlIf cIf_2MGmAg4I;
  ControlIf cIf_eO5alinQ;
  ControlDelay cDelay_pi1plrVw;
  ControlBinop cBinop_VQXRkjoK;
  ControlBinop cBinop_phzc9jBB;
  ControlIf cIf_pCT6yQKb;
  ControlIf cIf_7ow8wkio;
  ControlDelay cDelay_N6jFF4je;
  ControlBinop cBinop_auyoWr1O;
  ControlBinop cBinop_sBR4VQDE;
  ControlIf cIf_EtDIV13K;
  ControlIf cIf_UoJmAPt6;
  ControlDelay cDelay_dA78cskv;
  ControlBinop cBinop_pa8qYplT;
  ControlBinop cBinop_Vy2dy8K6;
  SignalVarf sVarf_FciMrh7A;
  SignalVarf sVarf_sGJ5QU99;
  SignalVarf sVarf_YiGFjNtA;
  SignalVarf sVarf_o0f20ZFx;
  SignalVarf sVarf_I074eljB;
  SignalVarf sVarf_Enpvvzf7;
  SignalVarf sVarf_ESi2m6xQ;
  SignalVarf sVarf_vtKKzz0H;
  ControlVar cVar_s49tb9Gz;
  ControlSlice cSlice_XonhxjVf;
  ControlVar cVar_guqXgR6Z;
  ControlSlice cSlice_GVc74ro7;
  ControlVar cVar_hV1NkMqv;
  ControlSlice cSlice_WDSjIx7g;
  ControlVar cVar_uXEJR3Fd;
  ControlSlice cSlice_2fXJZIBw;
  ControlVar cVar_lJK50tUt;
  ControlSlice cSlice_WVPWGkln;
  ControlVar cVar_Ypo3mK9Z;
  ControlDelay cDelay_VC5wicFc;
  ControlVar cVar_y4CPznaF;
  ControlIf cIf_drm4eO7W;
  ControlIf cIf_JZQ87MBa;
  ControlBinop cBinop_3JKJ0DOC;
  ControlBinop cBinop_RGeDf6jk;
  ControlBinop cBinop_evE5ndeQ;
  ControlBinop cBinop_xZLFAYmZ;
  ControlBinop cBinop_qW97Vcn3;
  ControlSlice cSlice_fzobyjvL;
  ControlVar cVar_QznjXeA5;
  SignalVarf sVarf_bvJmftTU;
  SignalVarf sVarf_7md44nbT;
  SignalVarf sVarf_0Tz0YEm5;
  SignalVarf sVarf_Sd6bzTq9;
  SignalVarf sVarf_flBSwLZ2;
  SignalVarf sVarf_wFwG0Gpc;
  ControlBinop cBinop_Psa86rZn;
  ControlBinop cBinop_z05kIrzh;
  ControlVar cVar_wFvqfChy;
  SignalVarf sVarf_BHWeCGZe;
  SignalVarf sVarf_5ID3hE9v;
  SignalVarf sVarf_eZAttdqz;
  SignalVarf sVarf_983xkA5g;
  ControlBinop cBinop_85OjOAZt;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
