/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_OdYFE2ZW);
  numBytes += sLine_init(&sLine_qTLFMXVu);
  numBytes += sLine_init(&sLine_xyZqn2W8);
  numBytes += sLine_init(&sLine_FJWQXHBA);
  numBytes += sLine_init(&sLine_ePaHBDLc);
  numBytes += sLine_init(&sLine_xRHeOaag);
  numBytes += sLine_init(&sLine_MyhzOjSR);
  numBytes += sLine_init(&sLine_1RseGAD7);
  numBytes += sLine_init(&sLine_rbdDuGwt);
  numBytes += sLine_init(&sLine_9OuW3cUm);
  numBytes += sLine_init(&sLine_57HKroR8);
  numBytes += sLine_init(&sLine_aPlGpQMT);
  numBytes += sEnv_init(&sEnv_e56GlJo6, 512, 256);
  numBytes += sEnv_init(&sEnv_VwAPW3Gb, 512, 256);
  numBytes += sLine_init(&sLine_3xVt32ck);
  numBytes += sLine_init(&sLine_wCTiz1Db);
  numBytes += sLine_init(&sLine_yZs5VTQ2);
  numBytes += sLine_init(&sLine_2DDJ0GpH);
  numBytes += sLine_init(&sLine_Sjp13NYU);
  numBytes += sLine_init(&sLine_YOW7NTXU);
  numBytes += sLine_init(&sLine_M9LF4GkO);
  numBytes += sLine_init(&sLine_CvFWf12E);
  numBytes += sLine_init(&sLine_eqN7Yqcq);
  numBytes += sLine_init(&sLine_m7akqlsg);
  numBytes += sLine_init(&sLine_z9c8XSaw);
  numBytes += sLine_init(&sLine_1OofMhc1);
  numBytes += sLine_init(&sLine_xvMFJyO9);
  numBytes += sLine_init(&sLine_FHfZU0Ie);
  numBytes += sLine_init(&sLine_IKjIYLLV);
  numBytes += sLine_init(&sLine_tlKVhyUf);
  numBytes += sLine_init(&sLine_JKzjIAoE);
  numBytes += sLine_init(&sLine_I47n6Mnz);
  numBytes += sEnv_init(&sEnv_ahZGbell, 512, 256);
  numBytes += sEnv_init(&sEnv_3kPndpho, 512, 256);
  numBytes += sLine_init(&sLine_XiS8VxwN);
  numBytes += sLine_init(&sLine_YuJNbGwd);
  numBytes += sLine_init(&sLine_lrgaZmrA);
  numBytes += sLine_init(&sLine_LyMURubq);
  numBytes += sLine_init(&sLine_eouQKh8m);
  numBytes += sLine_init(&sLine_iP6Swx8R);
  numBytes += sLine_init(&sLine_NdFvMSEr);
  numBytes += sLine_init(&sLine_lbMpUuxD);
  numBytes += cVar_init_f(&cVar_7JQv1du6, 0.0f);
  numBytes += cVar_init_f(&cVar_0yubj265, 0.0f);
  numBytes += cVar_init_f(&cVar_762OaX1y, 0.0f);
  numBytes += cVar_init_f(&cVar_azc80sQj, 0.0f);
  numBytes += cVar_init_f(&cVar_CXnXLxuk, 0.0f);
  numBytes += cVar_init_f(&cVar_rhBqkRAo, 1.0f);
  numBytes += cVar_init_f(&cVar_uCZYmwuY, 0.0f);
  numBytes += cVar_init_f(&cVar_aO6mXF1l, 0.0f);
  numBytes += cIf_init(&cIf_iYr72Pkh, false);
  numBytes += cIf_init(&cIf_Nc40jQQe, false);
  numBytes += cDelay_init(this, &cDelay_skmvLwHA, 10.0f);
  numBytes += cIf_init(&cIf_r9aIvHUZ, false);
  numBytes += cIf_init(&cIf_Ya2T9MrT, false);
  numBytes += cDelay_init(this, &cDelay_ikX2ZlzB, 10.0f);
  numBytes += cIf_init(&cIf_GODJ4QD4, false);
  numBytes += cIf_init(&cIf_HkwBdGA7, false);
  numBytes += cDelay_init(this, &cDelay_PfwUpue9, 10.0f);
  numBytes += cIf_init(&cIf_u0qYzRtV, false);
  numBytes += cIf_init(&cIf_j9RvSHtg, false);
  numBytes += cDelay_init(this, &cDelay_QDq6Za7j, 10.0f);
  numBytes += cIf_init(&cIf_SBn4boLP, false);
  numBytes += cIf_init(&cIf_e6nfrpYs, false);
  numBytes += cDelay_init(this, &cDelay_yuOS3ObS, 10.0f);
  numBytes += cIf_init(&cIf_IvlMdM7O, false);
  numBytes += cIf_init(&cIf_7Nj7qeDk, false);
  numBytes += cDelay_init(this, &cDelay_xmHlM4xh, 10.0f);
  numBytes += cIf_init(&cIf_bXSHrEVy, false);
  numBytes += cIf_init(&cIf_15I0XmjE, false);
  numBytes += cDelay_init(this, &cDelay_Wfiwpdgb, 10.0f);
  numBytes += cIf_init(&cIf_tr8PtH7O, false);
  numBytes += cIf_init(&cIf_IBCwvfBk, false);
  numBytes += cDelay_init(this, &cDelay_aGnfXdBN, 10.0f);
  numBytes += cIf_init(&cIf_1QrfwbRp, false);
  numBytes += cIf_init(&cIf_k9KX7bor, false);
  numBytes += cDelay_init(this, &cDelay_vZ1oB6uW, 10.0f);
  numBytes += cIf_init(&cIf_ERtBMAkv, false);
  numBytes += cIf_init(&cIf_5eJWVdFZ, false);
  numBytes += cDelay_init(this, &cDelay_WlSusi5l, 10.0f);
  numBytes += cIf_init(&cIf_WFACJoV9, false);
  numBytes += cIf_init(&cIf_2OaJrHoW, false);
  numBytes += cDelay_init(this, &cDelay_LL8O6MzO, 10.0f);
  numBytes += cIf_init(&cIf_lUMZ68Rl, false);
  numBytes += cIf_init(&cIf_MQdikn15, false);
  numBytes += cDelay_init(this, &cDelay_iNmx2BhP, 10.0f);
  numBytes += sVarf_init(&sVarf_BgyxzY6l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hYpfVyV6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wtJLH7pl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5ghGu2Gw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NkW9wt3g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JjTZtcMe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rtjp5K7U, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L1IxDtji, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_wXB3ObEs, 0.0f);
  numBytes += cSlice_init(&cSlice_R7NJzqH1, 1, -1);
  numBytes += cVar_init_f(&cVar_2ivQmAM7, 1.0f);
  numBytes += cSlice_init(&cSlice_cQrKn7nz, 1, -1);
  numBytes += cVar_init_f(&cVar_rAHckH8I, 0.0f);
  numBytes += cSlice_init(&cSlice_YYS0IrJo, 1, -1);
  numBytes += cVar_init_f(&cVar_SplAAonJ, 512.0f);
  numBytes += cSlice_init(&cSlice_tp9YZB6o, 1, -1);
  numBytes += cVar_init_f(&cVar_pvXWuLGm, 1.0f);
  numBytes += cSlice_init(&cSlice_9YRLzpYj, 1, -1);
  numBytes += cVar_init_f(&cVar_8E3LIhgM, 1.0f);
  numBytes += cDelay_init(this, &cDelay_8tcChfHu, 20.0f);
  numBytes += cVar_init_f(&cVar_xoIfLDeC, 0.0f);
  numBytes += cIf_init(&cIf_qgcxQfL5, false);
  numBytes += cIf_init(&cIf_Bt9R4UR0, false);
  numBytes += cBinop_init(&cBinop_bxLOiIxD, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_SrhOi9rp, 1, -1);
  numBytes += cVar_init_f(&cVar_00zUYIUP, 0.0f);
  numBytes += sVarf_init(&sVarf_BoUtqCEr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jX4bZ4ri, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0oSk3EKJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6X0iqXCc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vNONVIya, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CylrREDA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_yVWmBeJz, 0.0f);
  numBytes += cVar_init_f(&cVar_rAmdhNOr, 0.0f);
  numBytes += cIf_init(&cIf_EIW7Zzfe, false);
  numBytes += cIf_init(&cIf_yqPEVnbP, false);
  numBytes += cDelay_init(this, &cDelay_301qgHag, 10.0f);
  numBytes += cIf_init(&cIf_D6r2EpmY, false);
  numBytes += cIf_init(&cIf_DLtqFPsH, false);
  numBytes += cDelay_init(this, &cDelay_HoQq5N9I, 10.0f);
  numBytes += cIf_init(&cIf_XaEtaaZw, false);
  numBytes += cIf_init(&cIf_ryY2smPG, false);
  numBytes += cDelay_init(this, &cDelay_PmWi4n1a, 10.0f);
  numBytes += cIf_init(&cIf_V2UT4hxy, false);
  numBytes += cIf_init(&cIf_Y8SIrEKg, false);
  numBytes += cDelay_init(this, &cDelay_9zmooo9j, 10.0f);
  numBytes += cIf_init(&cIf_wNd2A3II, false);
  numBytes += cIf_init(&cIf_nZukfFGb, false);
  numBytes += cDelay_init(this, &cDelay_Dm4WV4x6, 10.0f);
  numBytes += cIf_init(&cIf_yDxxXTUA, false);
  numBytes += cIf_init(&cIf_wBEO8yrB, false);
  numBytes += cDelay_init(this, &cDelay_oqYN3MK0, 10.0f);
  numBytes += cIf_init(&cIf_2PxQ1Abu, false);
  numBytes += cIf_init(&cIf_SdpCOTnw, false);
  numBytes += cDelay_init(this, &cDelay_b7DJI0BF, 10.0f);
  numBytes += cIf_init(&cIf_SxqHKOtk, false);
  numBytes += cIf_init(&cIf_5qbnhLUC, false);
  numBytes += cDelay_init(this, &cDelay_yINUTumI, 10.0f);
  numBytes += cIf_init(&cIf_HiaZZKlf, false);
  numBytes += cIf_init(&cIf_PWMxvvnV, false);
  numBytes += cDelay_init(this, &cDelay_lrPVhDDa, 10.0f);
  numBytes += cIf_init(&cIf_2MGmAg4I, false);
  numBytes += cIf_init(&cIf_eO5alinQ, false);
  numBytes += cDelay_init(this, &cDelay_pi1plrVw, 10.0f);
  numBytes += cIf_init(&cIf_pCT6yQKb, false);
  numBytes += cIf_init(&cIf_7ow8wkio, false);
  numBytes += cDelay_init(this, &cDelay_N6jFF4je, 10.0f);
  numBytes += cIf_init(&cIf_EtDIV13K, false);
  numBytes += cIf_init(&cIf_UoJmAPt6, false);
  numBytes += cDelay_init(this, &cDelay_dA78cskv, 10.0f);
  numBytes += sVarf_init(&sVarf_FciMrh7A, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sGJ5QU99, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YiGFjNtA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o0f20ZFx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I074eljB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Enpvvzf7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ESi2m6xQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vtKKzz0H, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_s49tb9Gz, 0.0f);
  numBytes += cSlice_init(&cSlice_XonhxjVf, 1, -1);
  numBytes += cVar_init_f(&cVar_guqXgR6Z, 1.0f);
  numBytes += cSlice_init(&cSlice_GVc74ro7, 1, -1);
  numBytes += cVar_init_f(&cVar_hV1NkMqv, 0.0f);
  numBytes += cSlice_init(&cSlice_WDSjIx7g, 1, -1);
  numBytes += cVar_init_f(&cVar_uXEJR3Fd, 512.0f);
  numBytes += cSlice_init(&cSlice_2fXJZIBw, 1, -1);
  numBytes += cVar_init_f(&cVar_lJK50tUt, 1.0f);
  numBytes += cSlice_init(&cSlice_WVPWGkln, 1, -1);
  numBytes += cVar_init_f(&cVar_Ypo3mK9Z, 1.0f);
  numBytes += cDelay_init(this, &cDelay_VC5wicFc, 20.0f);
  numBytes += cVar_init_f(&cVar_y4CPznaF, 0.0f);
  numBytes += cIf_init(&cIf_drm4eO7W, false);
  numBytes += cIf_init(&cIf_JZQ87MBa, false);
  numBytes += cBinop_init(&cBinop_3JKJ0DOC, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_fzobyjvL, 1, -1);
  numBytes += cVar_init_f(&cVar_QznjXeA5, 0.0f);
  numBytes += sVarf_init(&sVarf_bvJmftTU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7md44nbT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0Tz0YEm5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Sd6bzTq9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_flBSwLZ2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wFwG0Gpc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_wFvqfChy, 0.0f);
  numBytes += sVarf_init(&sVarf_BHWeCGZe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5ID3hE9v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eZAttdqz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_983xkA5g, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_e56GlJo6);
  sEnv_free(&sEnv_VwAPW3Gb);
  sEnv_free(&sEnv_ahZGbell);
  sEnv_free(&sEnv_3kPndpho);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zYNWgLqh_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VbSxYKvE_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5dIlDU5v_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xyfKsSS9_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sQXIvQXD_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xczmOinX_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DZeZNVK6_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o2AKfTjP_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YznSQQJL_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kh742vqr_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dnr253R3_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mrcpqqza_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uiYdpQlh_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cu8P33fD_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1kXLOZrb_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rlvSHxsc_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5NCmHojW_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PQMSY6Ek_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tU8MIyiI_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dUFjtQ3I_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Unwajoxp_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_7JQv1du6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HSHGEekV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_6BQRYsCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fGelnqGB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_fGelnqGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_TpZOLF2E_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TpZOLF2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cQZYry99_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cQZYry99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9AmRg3Ee_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cz2ZRdCU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Cz2ZRdCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lFCq2RZG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_9AmRg3Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_b2S5qWhT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_b2S5qWhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2f4w1GQD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lFCq2RZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nlFBWHDG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_nlFBWHDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lmEgpezY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2f4w1GQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J6raJGWw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_lmEgpezY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a2VzWsrR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_0yubj265_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KeQ9cpHC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_762OaX1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_99D1GOgs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_azc80sQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QfODRbU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_CXnXLxuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCcdI6tu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_rhBqkRAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5ITjzpUR_sendMessage);
  cMsg_XL6IamBH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_5ITjzpUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rhBqkRAo, 1, m, &cVar_rhBqkRAo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4gXbGdu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aexdeCJA_sendMessage(_c, 0, m);
  cMsg_v7fd5re8_sendMessage(_c, 0, m);
  cMsg_t4pZ68zC_sendMessage(_c, 0, m);
  cMsg_Riy2AEtg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_uCZYmwuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b3usDJux_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_aO6mXF1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M7GIz93X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_XTl26tdk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bazcJGxv_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lPMxG0I1_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hYiBycDS_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bUZBo1MH_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_14vMpxc5_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4bhhMZ8p_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_bazcJGxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2gZNNEd4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_lPMxG0I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vadhuTFD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_hYiBycDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0rLbquXE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_bUZBo1MH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pI856j18_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_14vMpxc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8DkY0JS8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_4bhhMZ8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cGBDY0aQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_iYr72Pkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ofS84xs6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Nc40jQQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_X6r6jsVG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_xrZeyfG8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PQ4lJI40_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PQ4lJI40_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_skmvLwHA, 1, m, &cDelay_skmvLwHA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_olNIAnJA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_skmvLwHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_skmvLwHA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iYr72Pkh, 0, m, &cIf_iYr72Pkh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PQ4lJI40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_skmvLwHA, 0, m, &cDelay_skmvLwHA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_olNIAnJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_skmvLwHA, 0, m, &cDelay_skmvLwHA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3vvFmeul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jWYKU7Nh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Nqg1sFB8_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_faGIyA3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YFIkpubQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JqhG9Vzh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JqhG9Vzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xrZeyfG8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YFIkpubQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iYr72Pkh, 1, m, &cIf_iYr72Pkh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jWYKU7Nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Nc40jQQe, 1, m, &cIf_Nc40jQQe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Nqg1sFB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Nc40jQQe, 0, m, &cIf_Nc40jQQe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_X6r6jsVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FJWQXHBA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ofS84xs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FJWQXHBA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_r9aIvHUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Yx8AbdVX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Ya2T9MrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3MnnLvgb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_5G4Men85_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_f8eercvh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_f8eercvh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ikX2ZlzB, 1, m, &cDelay_ikX2ZlzB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_abiu7Z3y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ikX2ZlzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ikX2ZlzB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_r9aIvHUZ, 0, m, &cIf_r9aIvHUZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_f8eercvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ikX2ZlzB, 0, m, &cDelay_ikX2ZlzB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_abiu7Z3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ikX2ZlzB, 0, m, &cDelay_ikX2ZlzB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_M7Tb6T19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LGckCJRJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LBUCLgcZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aoeDb7lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zRz9Xtrc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uZ944S2Q_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zRz9Xtrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r9aIvHUZ, 1, m, &cIf_r9aIvHUZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_uZ944S2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5G4Men85_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_LGckCJRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ya2T9MrT, 1, m, &cIf_Ya2T9MrT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LBUCLgcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ya2T9MrT, 0, m, &cIf_Ya2T9MrT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3MnnLvgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MyhzOjSR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Yx8AbdVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MyhzOjSR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_GODJ4QD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lLcxLSOD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_HkwBdGA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L0lbIhzU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_bXvBn1ON_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_x4nmPEm8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_x4nmPEm8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PfwUpue9, 1, m, &cDelay_PfwUpue9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4dkywCpv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_PfwUpue9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PfwUpue9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GODJ4QD4, 0, m, &cIf_GODJ4QD4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_x4nmPEm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PfwUpue9, 0, m, &cDelay_PfwUpue9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4dkywCpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PfwUpue9, 0, m, &cDelay_PfwUpue9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_CnUKrkrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3JGEKIsF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RPnnc8k3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EAohF3nX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9uhFMDwa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4EM92KLx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4EM92KLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bXvBn1ON_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_9uhFMDwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GODJ4QD4, 1, m, &cIf_GODJ4QD4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3JGEKIsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HkwBdGA7, 1, m, &cIf_HkwBdGA7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RPnnc8k3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HkwBdGA7, 0, m, &cIf_HkwBdGA7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_L0lbIhzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9OuW3cUm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_lLcxLSOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9OuW3cUm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_u0qYzRtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6jRrkdtx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_j9RvSHtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QCvsAizq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_sHsV08wN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2dkft3N5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2dkft3N5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QDq6Za7j, 1, m, &cDelay_QDq6Za7j_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ykAZMh7U_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_QDq6Za7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QDq6Za7j, m);
  cIf_onMessage(_c, &Context(_c)->cIf_u0qYzRtV, 0, m, &cIf_u0qYzRtV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2dkft3N5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QDq6Za7j, 0, m, &cDelay_QDq6Za7j_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ykAZMh7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QDq6Za7j, 0, m, &cDelay_QDq6Za7j_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TKt5AOF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8gSYj0i2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UaJju0sm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ppctZRx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yq3PgNT8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CGKVt8jR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CGKVt8jR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sHsV08wN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Yq3PgNT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_u0qYzRtV, 1, m, &cIf_u0qYzRtV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UaJju0sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j9RvSHtg, 0, m, &cIf_j9RvSHtg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8gSYj0i2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j9RvSHtg, 1, m, &cIf_j9RvSHtg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QCvsAizq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ePaHBDLc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_6jRrkdtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ePaHBDLc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_SBn4boLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cBalV1kV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_e6nfrpYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_adirKwR5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_mi2G8wRp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TxZY1X2h_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TxZY1X2h_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yuOS3ObS, 1, m, &cDelay_yuOS3ObS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GK9YcLyi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_yuOS3ObS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yuOS3ObS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SBn4boLP, 0, m, &cIf_SBn4boLP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TxZY1X2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yuOS3ObS, 0, m, &cDelay_yuOS3ObS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GK9YcLyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yuOS3ObS, 0, m, &cDelay_yuOS3ObS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TWiFT9OQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lYYnvo7n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xx3NDhzJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TyTzMgw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_41oJAksR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XdtUlkq0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XdtUlkq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mi2G8wRp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_41oJAksR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SBn4boLP, 1, m, &cIf_SBn4boLP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Xx3NDhzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e6nfrpYs, 0, m, &cIf_e6nfrpYs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lYYnvo7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e6nfrpYs, 1, m, &cIf_e6nfrpYs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_adirKwR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1RseGAD7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_cBalV1kV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1RseGAD7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_IvlMdM7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kgTa3AcS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_7Nj7qeDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZHPP3u2m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_WdfokZ8t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3aRuivRK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3aRuivRK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xmHlM4xh, 1, m, &cDelay_xmHlM4xh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OJDiSrH7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_xmHlM4xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xmHlM4xh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_IvlMdM7O, 0, m, &cIf_IvlMdM7O_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3aRuivRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xmHlM4xh, 0, m, &cDelay_xmHlM4xh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OJDiSrH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xmHlM4xh, 0, m, &cDelay_xmHlM4xh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ocgjJlKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2diXqyjh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iY3taDYg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hBQ7UlCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a9PGw6hq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jQhirGAv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jQhirGAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WdfokZ8t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_a9PGw6hq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IvlMdM7O, 1, m, &cIf_IvlMdM7O_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iY3taDYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Nj7qeDk, 0, m, &cIf_7Nj7qeDk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2diXqyjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7Nj7qeDk, 1, m, &cIf_7Nj7qeDk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZHPP3u2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_57HKroR8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_kgTa3AcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_57HKroR8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_bXSHrEVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_16Lb8A0E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_15I0XmjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BL9zvKBx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Gz1AgyDL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aICiPseX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aICiPseX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Wfiwpdgb, 1, m, &cDelay_Wfiwpdgb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YTTDIPTs_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Wfiwpdgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Wfiwpdgb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bXSHrEVy, 0, m, &cIf_bXSHrEVy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aICiPseX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wfiwpdgb, 0, m, &cDelay_Wfiwpdgb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YTTDIPTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Wfiwpdgb, 0, m, &cDelay_Wfiwpdgb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Nmpdst3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZZdBmab6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ZtmSP84_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6z73nGpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SnIPXpo8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mhDc5CMt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SnIPXpo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bXSHrEVy, 1, m, &cIf_bXSHrEVy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mhDc5CMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Gz1AgyDL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ZZdBmab6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_15I0XmjE, 1, m, &cIf_15I0XmjE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0ZtmSP84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_15I0XmjE, 0, m, &cIf_15I0XmjE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BL9zvKBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xRHeOaag, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_16Lb8A0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xRHeOaag, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_tr8PtH7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0uKihDC7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_IBCwvfBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aKjqXcdD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_a3sF2irK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lPi8EiT6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lPi8EiT6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_aGnfXdBN, 1, m, &cDelay_aGnfXdBN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iT1Q8Im1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_aGnfXdBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aGnfXdBN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tr8PtH7O, 0, m, &cIf_tr8PtH7O_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lPi8EiT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_aGnfXdBN, 0, m, &cDelay_aGnfXdBN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iT1Q8Im1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aGnfXdBN, 0, m, &cDelay_aGnfXdBN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YYhpt16t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B0kfJBuY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WW90gvbq_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_i9N7tFc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TczP8Ql1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6n1AcyfV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TczP8Ql1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tr8PtH7O, 1, m, &cIf_tr8PtH7O_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6n1AcyfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_a3sF2irK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_B0kfJBuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IBCwvfBk, 1, m, &cIf_IBCwvfBk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WW90gvbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IBCwvfBk, 0, m, &cIf_IBCwvfBk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aKjqXcdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rbdDuGwt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0uKihDC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rbdDuGwt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_1QrfwbRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ivivsd6D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_k9KX7bor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_92x1jISI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_iwbOYo4e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_P22I5ffT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_P22I5ffT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vZ1oB6uW, 1, m, &cDelay_vZ1oB6uW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OhbZ7r0c_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vZ1oB6uW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vZ1oB6uW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1QrfwbRp, 0, m, &cIf_1QrfwbRp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_P22I5ffT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vZ1oB6uW, 0, m, &cDelay_vZ1oB6uW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OhbZ7r0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vZ1oB6uW, 0, m, &cDelay_vZ1oB6uW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_X5QpsEVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SrPLRqUY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TYNJ4unl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cU8EiNOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PlztDSl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XJBP76cM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XJBP76cM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iwbOYo4e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_1PlztDSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1QrfwbRp, 1, m, &cIf_1QrfwbRp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SrPLRqUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k9KX7bor, 1, m, &cIf_k9KX7bor_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TYNJ4unl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k9KX7bor, 0, m, &cIf_k9KX7bor_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_92x1jISI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aPlGpQMT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Ivivsd6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aPlGpQMT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ERtBMAkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MSMuIXpz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_5eJWVdFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aXMXG5tW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_WZ6vmwDy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kDJ4BcGS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kDJ4BcGS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WlSusi5l, 1, m, &cDelay_WlSusi5l_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YEgwjJjd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_WlSusi5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WlSusi5l, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ERtBMAkv, 0, m, &cIf_ERtBMAkv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kDJ4BcGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WlSusi5l, 0, m, &cDelay_WlSusi5l_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YEgwjJjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WlSusi5l, 0, m, &cDelay_WlSusi5l_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gVgQ9Xrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fKJmqzRU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IxaXcYUY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_pr8xdGnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AWROS5NJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2oeWg6Mi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2oeWg6Mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WZ6vmwDy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_AWROS5NJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ERtBMAkv, 1, m, &cIf_ERtBMAkv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IxaXcYUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5eJWVdFZ, 0, m, &cIf_5eJWVdFZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fKJmqzRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5eJWVdFZ, 1, m, &cIf_5eJWVdFZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aXMXG5tW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OdYFE2ZW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_MSMuIXpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OdYFE2ZW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_WFACJoV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_E5sPrmK6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_2OaJrHoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bFhfi6dp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_73P8Gboz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_710N6Nca_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_710N6Nca_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LL8O6MzO, 1, m, &cDelay_LL8O6MzO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WMlivmZ5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_LL8O6MzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LL8O6MzO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WFACJoV9, 0, m, &cIf_WFACJoV9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_710N6Nca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LL8O6MzO, 0, m, &cDelay_LL8O6MzO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WMlivmZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LL8O6MzO, 0, m, &cDelay_LL8O6MzO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_w2WBc08P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wlx0ycdE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wC0ig0jR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_OuKKMCA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MyKTBVnr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LWXJ85zo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LWXJ85zo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_73P8Gboz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_MyKTBVnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WFACJoV9, 1, m, &cIf_WFACJoV9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wlx0ycdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2OaJrHoW, 1, m, &cIf_2OaJrHoW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wC0ig0jR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2OaJrHoW, 0, m, &cIf_2OaJrHoW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bFhfi6dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qTLFMXVu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_E5sPrmK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qTLFMXVu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_lUMZ68Rl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WpHP0s7l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_MQdikn15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jMyxC3JP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_E9nMdqzS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mgfupNId_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mgfupNId_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_iNmx2BhP, 1, m, &cDelay_iNmx2BhP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iLX1Gh61_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_iNmx2BhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iNmx2BhP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lUMZ68Rl, 0, m, &cIf_lUMZ68Rl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mgfupNId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_iNmx2BhP, 0, m, &cDelay_iNmx2BhP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iLX1Gh61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_iNmx2BhP, 0, m, &cDelay_iNmx2BhP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YcfAd8rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ORVMsyA1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NzfBpZwf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AizZFk32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9yRfA8ry_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cjcDmMY1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cjcDmMY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_E9nMdqzS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_9yRfA8ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lUMZ68Rl, 1, m, &cIf_lUMZ68Rl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NzfBpZwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MQdikn15, 0, m, &cIf_MQdikn15_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ORVMsyA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MQdikn15, 1, m, &cIf_MQdikn15_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jMyxC3JP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xyZqn2W8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_WpHP0s7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xyZqn2W8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_2gZNNEd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_fREJzH3M_sendMessage(_c, 0, m);
  cMsg_11x3eno5_sendMessage(_c, 0, m);
  cMsg_dnfenZSx_sendMessage(_c, 0, m);
  cMsg_KKTZQEii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_vadhuTFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_fREJzH3M_sendMessage(_c, 0, m);
  cMsg_xoErCpzT_sendMessage(_c, 0, m);
  cMsg_lkCEiASL_sendMessage(_c, 0, m);
  cMsg_xnOuiyu4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0rLbquXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_fKb3DhFP_sendMessage(_c, 0, m);
  cMsg_xoErCpzT_sendMessage(_c, 0, m);
  cMsg_KKTZQEii_sendMessage(_c, 0, m);
  cMsg_rLu3NZJS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_pI856j18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_fKb3DhFP_sendMessage(_c, 0, m);
  cMsg_QVDaw4wA_sendMessage(_c, 0, m);
  cMsg_dnfenZSx_sendMessage(_c, 0, m);
  cMsg_7inBnPHF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8DkY0JS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_amHIreOQ_sendMessage(_c, 0, m);
  cMsg_xnOuiyu4_sendMessage(_c, 0, m);
  cMsg_UtujnAn1_sendMessage(_c, 0, m);
  cMsg_dnfenZSx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cGBDY0aQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_amHIreOQ_sendMessage(_c, 0, m);
  cMsg_7inBnPHF_sendMessage(_c, 0, m);
  cMsg_xoErCpzT_sendMessage(_c, 0, m);
  cMsg_QWhzIAtD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xNI2wtIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_faGIyA3e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3vvFmeul_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JYXv2oVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_faGIyA3e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3vvFmeul_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_jqYQBbiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aoeDb7lh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_M7Tb6T19_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_k8uEXcL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aoeDb7lh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_M7Tb6T19_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_24HX6ptG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EAohF3nX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CnUKrkrh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_l56FnBzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EAohF3nX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CnUKrkrh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fREJzH3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_xNI2wtIH_sendMessage(_c, 0, m);
  cMsg_k8uEXcL0_sendMessage(_c, 0, m);
  cMsg_l56FnBzH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_fKb3DhFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_JYXv2oVD_sendMessage(_c, 0, m);
  cMsg_jqYQBbiV_sendMessage(_c, 0, m);
  cMsg_l56FnBzH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_amHIreOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_JYXv2oVD_sendMessage(_c, 0, m);
  cMsg_k8uEXcL0_sendMessage(_c, 0, m);
  cMsg_24HX6ptG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_JCAUMN2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ppctZRx6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TKt5AOF2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FbNNFCad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ppctZRx6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TKt5AOF2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ERyINhpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TyTzMgw5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TWiFT9OQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rdJE4VnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TyTzMgw5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TWiFT9OQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qby20v9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hBQ7UlCA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ocgjJlKV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9BbxcshO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hBQ7UlCA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ocgjJlKV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xoErCpzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_FbNNFCad_sendMessage(_c, 0, m);
  cMsg_rdJE4VnD_sendMessage(_c, 0, m);
  cMsg_9BbxcshO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_11x3eno5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_FbNNFCad_sendMessage(_c, 0, m);
  cMsg_ERyINhpB_sendMessage(_c, 0, m);
  cMsg_qby20v9f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_QVDaw4wA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_JCAUMN2H_sendMessage(_c, 0, m);
  cMsg_rdJE4VnD_sendMessage(_c, 0, m);
  cMsg_qby20v9f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_C6yRGsXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pr8xdGnj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gVgQ9Xrj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IcJeKxGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pr8xdGnj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gVgQ9Xrj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9r1s5L8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OuKKMCA7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w2WBc08P_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0CaWCpRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OuKKMCA7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w2WBc08P_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xDUhc97p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AizZFk32_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YcfAd8rw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aixDt6rh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AizZFk32_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YcfAd8rw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7inBnPHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_C6yRGsXN_sendMessage(_c, 0, m);
  cMsg_0CaWCpRw_sendMessage(_c, 0, m);
  cMsg_aixDt6rh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xnOuiyu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_IcJeKxGx_sendMessage(_c, 0, m);
  cMsg_9r1s5L8Y_sendMessage(_c, 0, m);
  cMsg_aixDt6rh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KKTZQEii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_IcJeKxGx_sendMessage(_c, 0, m);
  cMsg_0CaWCpRw_sendMessage(_c, 0, m);
  cMsg_xDUhc97p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_inqkBf1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6z73nGpX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Nmpdst3C_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qITCV7mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6z73nGpX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Nmpdst3C_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_17k0jcoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i9N7tFc5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YYhpt16t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3DCZ9tQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_i9N7tFc5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YYhpt16t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_R29f8ZzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cU8EiNOL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_X5QpsEVL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_d8rGzi34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cU8EiNOL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_X5QpsEVL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dnfenZSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_qITCV7mn_sendMessage(_c, 0, m);
  cMsg_3DCZ9tQq_sendMessage(_c, 0, m);
  cMsg_d8rGzi34_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lkCEiASL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_qITCV7mn_sendMessage(_c, 0, m);
  cMsg_17k0jcoV_sendMessage(_c, 0, m);
  cMsg_R29f8ZzU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_QWhzIAtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_inqkBf1f_sendMessage(_c, 0, m);
  cMsg_17k0jcoV_sendMessage(_c, 0, m);
  cMsg_d8rGzi34_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_UtujnAn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_JCAUMN2H_sendMessage(_c, 0, m);
  cMsg_ERyINhpB_sendMessage(_c, 0, m);
  cMsg_9BbxcshO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_rLu3NZJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_inqkBf1f_sendMessage(_c, 0, m);
  cMsg_3DCZ9tQq_sendMessage(_c, 0, m);
  cMsg_R29f8ZzU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_wXB3ObEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aWlhwHH2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_pHi6BPiH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_R7NJzqH1, 0, m, &cSlice_R7NJzqH1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tRNRtnV1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_R7NJzqH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hp2XObpV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hp2XObpV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_2ivQmAM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hp2XObpV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_hp2XObpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kh742vqr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_XxVpAX1j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cQrKn7nz, 0, m, &cSlice_cQrKn7nz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hyMPpD0X_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_cQrKn7nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bHAJWYwU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bHAJWYwU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_rAHckH8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bHAJWYwU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_bHAJWYwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cu8P33fD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_hyMPpD0X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YYS0IrJo, 0, m, &cSlice_YYS0IrJo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pHi6BPiH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_YYS0IrJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_i9pAml96_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_i9pAml96_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_SplAAonJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i9pAml96_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_i9pAml96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YznSQQJL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_tRNRtnV1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tp9YZB6o, 0, m, &cSlice_tp9YZB6o_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HVE9GpQG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_tp9YZB6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fz1KQbxX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fz1KQbxX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_pvXWuLGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fz1KQbxX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_fz1KQbxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uiYdpQlh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_HVE9GpQG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9YRLzpYj, 0, m, &cSlice_9YRLzpYj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9MdKNKFO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_9YRLzpYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6QKB0EAa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6QKB0EAa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_8E3LIhgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6QKB0EAa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_6QKB0EAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mrcpqqza_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_idIatUoD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wj80bL2L_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wj80bL2L_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8tcChfHu, 1, m, &cDelay_8tcChfHu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qna0L5v4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8tcChfHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8tcChfHu, m);
  cMsg_0n0klmB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_wj80bL2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8tcChfHu, 0, m, &cDelay_8tcChfHu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Qna0L5v4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8tcChfHu, 0, m, &cDelay_8tcChfHu_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_xoIfLDeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bxLOiIxD, HV_BINOP_SUBTRACT, 0, m, &cBinop_bxLOiIxD_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_qgcxQfL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g5rWUKmW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Bt9R4UR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g5rWUKmW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_e56GlJo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xoIfLDeC, 0, m, &cVar_xoIfLDeC_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_VwAPW3Gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zag42cvD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nVwkdUjh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FUdR1jHs_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_bxLOiIxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jNB0beuA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jNB0beuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2SPpjU0h_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2SPpjU0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Qs9FzviJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_prKJJX3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eQBEH3H4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2w8aNEwN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2w8aNEwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zcn4POEh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_eQBEH3H4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qgcxQfL5, 1, m, &cIf_qgcxQfL5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kz64Mzjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bt9R4UR0, 1, m, &cIf_Bt9R4UR0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Zcn4POEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_qgcxQfL5, 0, m, &cIf_qgcxQfL5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Qs9FzviJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bt9R4UR0, 0, m, &cIf_Bt9R4UR0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nVwkdUjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bxLOiIxD, HV_BINOP_SUBTRACT, 1, m, &cBinop_bxLOiIxD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Zag42cvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_FUdR1jHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xoIfLDeC, 0, m, &cVar_xoIfLDeC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_g5rWUKmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3xVt32ck, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_9MdKNKFO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SrhOi9rp, 0, m, &cSlice_SrhOi9rp_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_SrhOi9rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wO3VICnK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wO3VICnK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_00zUYIUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wO3VICnK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_wO3VICnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Dnr253R3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_b3usDJux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YOW7NTXU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_M7GIz93X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2DDJ0GpH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_Io1tSZpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aO6mXF1l, 0, m, &cVar_aO6mXF1l_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aWlhwHH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sjp13NYU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_3UXf5GzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_idIatUoD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_yyeATnWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nwrj4KyY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0n0klmB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wCTiz1Db, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_nwrj4KyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wCTiz1Db, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_lL78mAUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_o7TdgUIn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_o7TdgUIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gsTMme3s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gsTMme3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yZs5VTQ2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_yVWmBeJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xKcy7jLI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_rAmdhNOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gNYE3rAY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_FOMLuUyd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vgfSOgBg_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B6g6wlIn_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tuP7HHnp_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vARB6Jyo_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08gfhtia_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tOdBnuEd_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_vgfSOgBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mny0HwDq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_B6g6wlIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m8P3IFfg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_tuP7HHnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lR8roPiq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_vARB6Jyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qp2j3Erg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_08gfhtia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w3RU5N2D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_tOdBnuEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gP44pU10_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_EIW7Zzfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LwLCWpoc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_yqPEVnbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nJObUSxF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_bh33jITe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WsGMeVb0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WsGMeVb0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_301qgHag, 1, m, &cDelay_301qgHag_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4OZTTxmj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_301qgHag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_301qgHag, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EIW7Zzfe, 0, m, &cIf_EIW7Zzfe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WsGMeVb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_301qgHag, 0, m, &cDelay_301qgHag_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4OZTTxmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_301qgHag, 0, m, &cDelay_301qgHag_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YgaKX6JP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6G8O57gH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iCNaTdNK_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8HmlL5yP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DT1vQoxR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8qQ69YcL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8qQ69YcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bh33jITe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_DT1vQoxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EIW7Zzfe, 1, m, &cIf_EIW7Zzfe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iCNaTdNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yqPEVnbP, 0, m, &cIf_yqPEVnbP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6G8O57gH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yqPEVnbP, 1, m, &cIf_yqPEVnbP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nJObUSxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m7akqlsg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LwLCWpoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m7akqlsg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_D6r2EpmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_awOaC6bb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_DLtqFPsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KWW0RGc3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_J6LI0ReY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HIvqqgng_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HIvqqgng_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HoQq5N9I, 1, m, &cDelay_HoQq5N9I_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dvUO0rWN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_HoQq5N9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HoQq5N9I, m);
  cIf_onMessage(_c, &Context(_c)->cIf_D6r2EpmY, 0, m, &cIf_D6r2EpmY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HIvqqgng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HoQq5N9I, 0, m, &cDelay_HoQq5N9I_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dvUO0rWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HoQq5N9I, 0, m, &cDelay_HoQq5N9I_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wc2pSUcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waRk8f44_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jAxItjb4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cU1s8oO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S6ieCX2x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TN77PaHY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TN77PaHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_J6LI0ReY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_S6ieCX2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D6r2EpmY, 1, m, &cIf_D6r2EpmY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jAxItjb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DLtqFPsH, 0, m, &cIf_DLtqFPsH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_waRk8f44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DLtqFPsH, 1, m, &cIf_DLtqFPsH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KWW0RGc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xvMFJyO9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_awOaC6bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xvMFJyO9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_XaEtaaZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wSlfr8YA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ryY2smPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wpftzEvy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_tdJ02S6T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1ywERTDS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1ywERTDS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PmWi4n1a, 1, m, &cDelay_PmWi4n1a_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wT8oaI1b_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_PmWi4n1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PmWi4n1a, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XaEtaaZw, 0, m, &cIf_XaEtaaZw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1ywERTDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PmWi4n1a, 0, m, &cDelay_PmWi4n1a_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wT8oaI1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PmWi4n1a, 0, m, &cDelay_PmWi4n1a_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_II5xuY53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iXMbrPd4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vPbNAzVW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UrOKX4G8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Le1eZxS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hBDmSqTA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9Le1eZxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XaEtaaZw, 1, m, &cIf_XaEtaaZw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hBDmSqTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tdJ02S6T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_vPbNAzVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ryY2smPG, 0, m, &cIf_ryY2smPG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iXMbrPd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ryY2smPG, 1, m, &cIf_ryY2smPG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wpftzEvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tlKVhyUf, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wSlfr8YA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tlKVhyUf, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_V2UT4hxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ujrL3SCY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Y8SIrEKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uOkzigdL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_9I0yzIhZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1bfbzEPQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1bfbzEPQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9zmooo9j, 1, m, &cDelay_9zmooo9j_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2tLjr39P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_9zmooo9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9zmooo9j, m);
  cIf_onMessage(_c, &Context(_c)->cIf_V2UT4hxy, 0, m, &cIf_V2UT4hxy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1bfbzEPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9zmooo9j, 0, m, &cDelay_9zmooo9j_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2tLjr39P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9zmooo9j, 0, m, &cDelay_9zmooo9j_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YOBraqYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YMCnzHMb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QymySCoN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VQEZiUGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vpOTZTtN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kZOXDfph_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vpOTZTtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V2UT4hxy, 1, m, &cIf_V2UT4hxy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kZOXDfph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9I0yzIhZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YMCnzHMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y8SIrEKg, 1, m, &cIf_Y8SIrEKg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QymySCoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y8SIrEKg, 0, m, &cIf_Y8SIrEKg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uOkzigdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z9c8XSaw, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ujrL3SCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z9c8XSaw, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_wNd2A3II_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0IWMqPNR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nZukfFGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KXpOtF5K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_fDDJJEXX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WxxCqGQx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WxxCqGQx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Dm4WV4x6, 1, m, &cDelay_Dm4WV4x6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K7cDvZ5T_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Dm4WV4x6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Dm4WV4x6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wNd2A3II, 0, m, &cIf_wNd2A3II_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WxxCqGQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dm4WV4x6, 0, m, &cDelay_Dm4WV4x6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_K7cDvZ5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dm4WV4x6, 0, m, &cDelay_Dm4WV4x6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hv8FbS3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hCKkiDsc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3t7zuXeM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ZjNRDsgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m6PyxyuQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_umWkxpBN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_m6PyxyuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wNd2A3II, 1, m, &cIf_wNd2A3II_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_umWkxpBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fDDJJEXX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hCKkiDsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nZukfFGb, 1, m, &cIf_nZukfFGb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3t7zuXeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nZukfFGb, 0, m, &cIf_nZukfFGb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KXpOtF5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FHfZU0Ie, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0IWMqPNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FHfZU0Ie, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_yDxxXTUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_V15eqFAj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_wBEO8yrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AbtYfQyn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_deissGp6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_r9Q8BVel_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_r9Q8BVel_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oqYN3MK0, 1, m, &cDelay_oqYN3MK0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8pt2i4dr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_oqYN3MK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oqYN3MK0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yDxxXTUA, 0, m, &cIf_yDxxXTUA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_r9Q8BVel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oqYN3MK0, 0, m, &cDelay_oqYN3MK0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8pt2i4dr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oqYN3MK0, 0, m, &cDelay_oqYN3MK0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_QR9o9Hbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_azE1lRMx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DOQ0DMFG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_q5mNASjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OvTX2op7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dy18FyQT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Dy18FyQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_deissGp6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_OvTX2op7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yDxxXTUA, 1, m, &cIf_yDxxXTUA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_azE1lRMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wBEO8yrB, 1, m, &cIf_wBEO8yrB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DOQ0DMFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wBEO8yrB, 0, m, &cIf_wBEO8yrB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AbtYfQyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JKzjIAoE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_V15eqFAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JKzjIAoE, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_2PxQ1Abu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HWxQPG7N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_SdpCOTnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0lDwEbH2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_mRizZxfN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ruu4K1xD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ruu4K1xD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_b7DJI0BF, 1, m, &cDelay_b7DJI0BF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2XTVuEwB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_b7DJI0BF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b7DJI0BF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2PxQ1Abu, 0, m, &cIf_2PxQ1Abu_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ruu4K1xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_b7DJI0BF, 0, m, &cDelay_b7DJI0BF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2XTVuEwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b7DJI0BF, 0, m, &cDelay_b7DJI0BF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BPGhF2Io_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GOqL1VJE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t6XzQVzG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Q1fsWXkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zz1lhom4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rQmxTBGe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zz1lhom4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2PxQ1Abu, 1, m, &cIf_2PxQ1Abu_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rQmxTBGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mRizZxfN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_t6XzQVzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SdpCOTnw, 0, m, &cIf_SdpCOTnw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GOqL1VJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SdpCOTnw, 1, m, &cIf_SdpCOTnw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0lDwEbH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1OofMhc1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HWxQPG7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1OofMhc1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_SxqHKOtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TFsgRuUW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_5qbnhLUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RJizaH24_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_qTub78fD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_VnnxixUW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_VnnxixUW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yINUTumI, 1, m, &cDelay_yINUTumI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k2TtRSml_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_yINUTumI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yINUTumI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SxqHKOtk, 0, m, &cIf_SxqHKOtk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VnnxixUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yINUTumI, 0, m, &cDelay_yINUTumI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_k2TtRSml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yINUTumI, 0, m, &cDelay_yINUTumI_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_75nfu1n4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hz5W5zx8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EN5lZnFj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Ojx8MO15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AMJPjHvT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5xjZpFgE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AMJPjHvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SxqHKOtk, 1, m, &cIf_SxqHKOtk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5xjZpFgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qTub78fD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hz5W5zx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5qbnhLUC, 1, m, &cIf_5qbnhLUC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EN5lZnFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5qbnhLUC, 0, m, &cIf_5qbnhLUC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RJizaH24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IKjIYLLV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_TFsgRuUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IKjIYLLV, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_HiaZZKlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sgsZWGzN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_PWMxvvnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cYhOSfmG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_WOqGrwMr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oKcf7ZYe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oKcf7ZYe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lrPVhDDa, 1, m, &cDelay_lrPVhDDa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_suCIzbIk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_lrPVhDDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lrPVhDDa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HiaZZKlf, 0, m, &cIf_HiaZZKlf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oKcf7ZYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lrPVhDDa, 0, m, &cDelay_lrPVhDDa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_suCIzbIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lrPVhDDa, 0, m, &cDelay_lrPVhDDa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_t9jg2vk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x9teX6bq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zQJxVljX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ftF9f5ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WPVDdepT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D1ZuHglb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WPVDdepT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HiaZZKlf, 1, m, &cIf_HiaZZKlf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_D1ZuHglb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WOqGrwMr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_x9teX6bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PWMxvvnV, 1, m, &cIf_PWMxvvnV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zQJxVljX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PWMxvvnV, 0, m, &cIf_PWMxvvnV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cYhOSfmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I47n6Mnz, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_sgsZWGzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I47n6Mnz, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_2MGmAg4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eEcpJAHp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_eO5alinQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xfjEqWFu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_xtCjgPvC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5iaF8oAG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5iaF8oAG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pi1plrVw, 1, m, &cDelay_pi1plrVw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sUUxaeE8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_pi1plrVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pi1plrVw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2MGmAg4I, 0, m, &cIf_2MGmAg4I_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5iaF8oAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pi1plrVw, 0, m, &cDelay_pi1plrVw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sUUxaeE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pi1plrVw, 0, m, &cDelay_pi1plrVw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VQXRkjoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z60X6onH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lb2nNcdi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_phzc9jBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YVy574L1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PYF2Xvjj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PYF2Xvjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xtCjgPvC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_YVy574L1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2MGmAg4I, 1, m, &cIf_2MGmAg4I_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Z60X6onH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eO5alinQ, 1, m, &cIf_eO5alinQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lb2nNcdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eO5alinQ, 0, m, &cIf_eO5alinQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xfjEqWFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M9LF4GkO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_eEcpJAHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M9LF4GkO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_pCT6yQKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3d8SK6Rg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_7ow8wkio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_06BQDFRw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_D9wv3iCt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ly7WiwPl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ly7WiwPl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_N6jFF4je, 1, m, &cDelay_N6jFF4je_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VSGNQ01U_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_N6jFF4je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N6jFF4je, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pCT6yQKb, 0, m, &cIf_pCT6yQKb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ly7WiwPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_N6jFF4je, 0, m, &cDelay_N6jFF4je_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VSGNQ01U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N6jFF4je, 0, m, &cDelay_N6jFF4je_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_auyoWr1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CVsTMay4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xuinAWgm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sBR4VQDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aduIA298_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mxRVRnDw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mxRVRnDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_D9wv3iCt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_aduIA298_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pCT6yQKb, 1, m, &cIf_pCT6yQKb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xuinAWgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7ow8wkio, 0, m, &cIf_7ow8wkio_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CVsTMay4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7ow8wkio, 1, m, &cIf_7ow8wkio_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_06BQDFRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CvFWf12E, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_3d8SK6Rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CvFWf12E, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_EtDIV13K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gLXEKLFS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_UoJmAPt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6hN2kL2I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_w0ZuQWi6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_x0qaZCLJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_x0qaZCLJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dA78cskv, 1, m, &cDelay_dA78cskv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R9kqkpvY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_dA78cskv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dA78cskv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EtDIV13K, 0, m, &cIf_EtDIV13K_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_x0qaZCLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dA78cskv, 0, m, &cDelay_dA78cskv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_R9kqkpvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dA78cskv, 0, m, &cDelay_dA78cskv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_pa8qYplT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x8AnlrvX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LxDcNo9U_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Vy2dy8K6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8HwBvoRD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1PKjA1Ah_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1PKjA1Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_w0ZuQWi6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_8HwBvoRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EtDIV13K, 1, m, &cIf_EtDIV13K_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LxDcNo9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UoJmAPt6, 0, m, &cIf_UoJmAPt6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_x8AnlrvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UoJmAPt6, 1, m, &cIf_UoJmAPt6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6hN2kL2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eqN7Yqcq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gLXEKLFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eqN7Yqcq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Mny0HwDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_UWJnkMDt_sendMessage(_c, 0, m);
  cMsg_ao63S0ko_sendMessage(_c, 0, m);
  cMsg_Ja9CqBd3_sendMessage(_c, 0, m);
  cMsg_R84YpPK9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_m8P3IFfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_UWJnkMDt_sendMessage(_c, 0, m);
  cMsg_1K9Kigmy_sendMessage(_c, 0, m);
  cMsg_pvXf87IU_sendMessage(_c, 0, m);
  cMsg_rop1urwr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lR8roPiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_gegn6sf4_sendMessage(_c, 0, m);
  cMsg_1K9Kigmy_sendMessage(_c, 0, m);
  cMsg_R84YpPK9_sendMessage(_c, 0, m);
  cMsg_YbySwaTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qp2j3Erg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_gegn6sf4_sendMessage(_c, 0, m);
  cMsg_DTnIMRqd_sendMessage(_c, 0, m);
  cMsg_Ja9CqBd3_sendMessage(_c, 0, m);
  cMsg_XDuAGMmz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_w3RU5N2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_RQnuMe52_sendMessage(_c, 0, m);
  cMsg_rop1urwr_sendMessage(_c, 0, m);
  cMsg_HVXxKwK8_sendMessage(_c, 0, m);
  cMsg_Ja9CqBd3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gP44pU10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_RQnuMe52_sendMessage(_c, 0, m);
  cMsg_XDuAGMmz_sendMessage(_c, 0, m);
  cMsg_1K9Kigmy_sendMessage(_c, 0, m);
  cMsg_sYvHFjrd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9nHXkom5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8HmlL5yP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YgaKX6JP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Eozbbgvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8HmlL5yP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YgaKX6JP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_T5IiOnSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cU1s8oO0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wc2pSUcT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Vhh6YyaG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cU1s8oO0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wc2pSUcT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_M5hPODDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UrOKX4G8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_II5xuY53_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_r5ffBfw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UrOKX4G8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_II5xuY53_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UWJnkMDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_9nHXkom5_sendMessage(_c, 0, m);
  cMsg_Vhh6YyaG_sendMessage(_c, 0, m);
  cMsg_r5ffBfw6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gegn6sf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Eozbbgvn_sendMessage(_c, 0, m);
  cMsg_T5IiOnSZ_sendMessage(_c, 0, m);
  cMsg_r5ffBfw6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RQnuMe52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Eozbbgvn_sendMessage(_c, 0, m);
  cMsg_Vhh6YyaG_sendMessage(_c, 0, m);
  cMsg_M5hPODDk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_M1TaECeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VQEZiUGz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YOBraqYT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_d30znDzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VQEZiUGz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YOBraqYT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UvdJaXkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZjNRDsgp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hv8FbS3z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Decpt5cH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZjNRDsgp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hv8FbS3z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LiB3EE93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_q5mNASjn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QR9o9Hbv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ecaAxu95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_q5mNASjn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QR9o9Hbv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1K9Kigmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_d30znDzS_sendMessage(_c, 0, m);
  cMsg_Decpt5cH_sendMessage(_c, 0, m);
  cMsg_ecaAxu95_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ao63S0ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_d30znDzS_sendMessage(_c, 0, m);
  cMsg_UvdJaXkO_sendMessage(_c, 0, m);
  cMsg_LiB3EE93_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_DTnIMRqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_M1TaECeB_sendMessage(_c, 0, m);
  cMsg_Decpt5cH_sendMessage(_c, 0, m);
  cMsg_LiB3EE93_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_oeRzk8YN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_phzc9jBB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VQXRkjoK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EpN9bpYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_phzc9jBB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VQXRkjoK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bXwCzMdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sBR4VQDE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_auyoWr1O_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ae7eFhpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sBR4VQDE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_auyoWr1O_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LFTR8dPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vy2dy8K6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pa8qYplT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6fnRN1Ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vy2dy8K6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pa8qYplT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XDuAGMmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_oeRzk8YN_sendMessage(_c, 0, m);
  cMsg_ae7eFhpp_sendMessage(_c, 0, m);
  cMsg_6fnRN1Ep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_rop1urwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_EpN9bpYm_sendMessage(_c, 0, m);
  cMsg_bXwCzMdZ_sendMessage(_c, 0, m);
  cMsg_6fnRN1Ep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_R84YpPK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_EpN9bpYm_sendMessage(_c, 0, m);
  cMsg_ae7eFhpp_sendMessage(_c, 0, m);
  cMsg_LFTR8dPA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jst82ZkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q1fsWXkt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BPGhF2Io_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vs6pih2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q1fsWXkt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BPGhF2Io_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CAwKOdc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ojx8MO15_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_75nfu1n4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_icl8EmaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Ojx8MO15_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_75nfu1n4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6xIgVBTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ftF9f5ps_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_t9jg2vk5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3PhYwgay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ftF9f5ps_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_t9jg2vk5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ja9CqBd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_vs6pih2g_sendMessage(_c, 0, m);
  cMsg_icl8EmaB_sendMessage(_c, 0, m);
  cMsg_3PhYwgay_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_pvXf87IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_vs6pih2g_sendMessage(_c, 0, m);
  cMsg_CAwKOdc1_sendMessage(_c, 0, m);
  cMsg_6xIgVBTQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_sYvHFjrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_jst82ZkH_sendMessage(_c, 0, m);
  cMsg_CAwKOdc1_sendMessage(_c, 0, m);
  cMsg_3PhYwgay_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HVXxKwK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_M1TaECeB_sendMessage(_c, 0, m);
  cMsg_UvdJaXkO_sendMessage(_c, 0, m);
  cMsg_ecaAxu95_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_YbySwaTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_jst82ZkH_sendMessage(_c, 0, m);
  cMsg_icl8EmaB_sendMessage(_c, 0, m);
  cMsg_6xIgVBTQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_s49tb9Gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vel3p3AZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_CyrANxZA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XonhxjVf, 0, m, &cSlice_XonhxjVf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vq2OoRVv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_XonhxjVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_i97CgUcv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_i97CgUcv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_guqXgR6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i97CgUcv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_i97CgUcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rlvSHxsc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_rrKfULrt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GVc74ro7, 0, m, &cSlice_GVc74ro7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pOa2oyzn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_GVc74ro7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xLGS6OPw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xLGS6OPw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_hV1NkMqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xLGS6OPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_xLGS6OPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dUFjtQ3I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_pOa2oyzn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WDSjIx7g, 0, m, &cSlice_WDSjIx7g_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CyrANxZA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_WDSjIx7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5VV0KldO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5VV0KldO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_uXEJR3Fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5VV0KldO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_5VV0KldO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1kXLOZrb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_vq2OoRVv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2fXJZIBw, 0, m, &cSlice_2fXJZIBw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5gAUG0Ww_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_2fXJZIBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6QuFgl2d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6QuFgl2d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_lJK50tUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6QuFgl2d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_6QuFgl2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tU8MIyiI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_5gAUG0Ww_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WVPWGkln, 0, m, &cSlice_WVPWGkln_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iBFwdca6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_WVPWGkln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cANDXHLe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cANDXHLe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_Ypo3mK9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cANDXHLe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_cANDXHLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PQMSY6Ek_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_tmEclVhB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GOCq1bcO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GOCq1bcO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VC5wicFc, 1, m, &cDelay_VC5wicFc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XDSXmLMJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_VC5wicFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VC5wicFc, m);
  cMsg_A1d60PoZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_GOCq1bcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VC5wicFc, 0, m, &cDelay_VC5wicFc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XDSXmLMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VC5wicFc, 0, m, &cDelay_VC5wicFc_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_y4CPznaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3JKJ0DOC, HV_BINOP_SUBTRACT, 0, m, &cBinop_3JKJ0DOC_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_drm4eO7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_89HdGs8o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_JZQ87MBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_89HdGs8o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_ahZGbell_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y4CPznaF, 0, m, &cVar_y4CPznaF_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_3kPndpho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CLovvLvp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cyb9bYvR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7r1b3kC5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3JKJ0DOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zzFbmgwc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zzFbmgwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RGeDf6jk_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RGeDf6jk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qW97Vcn3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_evE5ndeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xk7Acg42_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UycYiFYt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UycYiFYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oMKGBLz5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Xk7Acg42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_drm4eO7W, 1, m, &cIf_drm4eO7W_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xZLFAYmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JZQ87MBa, 1, m, &cIf_JZQ87MBa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oMKGBLz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_drm4eO7W, 0, m, &cIf_drm4eO7W_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qW97Vcn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JZQ87MBa, 0, m, &cIf_JZQ87MBa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Cyb9bYvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3JKJ0DOC, HV_BINOP_SUBTRACT, 1, m, &cBinop_3JKJ0DOC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CLovvLvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_7r1b3kC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y4CPznaF, 0, m, &cVar_y4CPznaF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_89HdGs8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XiS8VxwN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_iBFwdca6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fzobyjvL, 0, m, &cSlice_fzobyjvL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_fzobyjvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_w8S9Nfat_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_w8S9Nfat_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_QznjXeA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w8S9Nfat_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_w8S9Nfat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5NCmHojW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_xKcy7jLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iP6Swx8R, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gNYE3rAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LyMURubq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_Psa86rZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rAmdhNOr, 0, m, &cVar_rAmdhNOr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vel3p3AZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eouQKh8m, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_EgCMiQMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tmEclVhB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_NwUxXTjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g3eSq71z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_A1d60PoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YuJNbGwd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_g3eSq71z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YuJNbGwd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_TJ6WsnTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_z05kIrzh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_z05kIrzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fYotLIXD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_fYotLIXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lrgaZmrA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_wFvqfChy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HtK5okA8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_J6raJGWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lbMpUuxD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_a2VzWsrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NdFvMSEr, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_KeQ9cpHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o2AKfTjP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HSHGEekV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XxVpAX1j_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rrKfULrt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QfODRbU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XxVpAX1j_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rrKfULrt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_85OjOAZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0yubj265, 0, m, &cVar_0yubj265_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_99D1GOgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XxVpAX1j_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rrKfULrt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BCcdI6tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XxVpAX1j_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rrKfULrt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XL6IamBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XxVpAX1j_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rrKfULrt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_aexdeCJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_azc80sQj, 0, m, &cVar_azc80sQj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_v7fd5re8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_762OaX1y, 0, m, &cVar_762OaX1y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CXnXLxuk, 0, m, &cVar_CXnXLxuk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_t4pZ68zC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_85OjOAZt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mj2X4sCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_rhBqkRAo, 0, m, &cVar_rhBqkRAo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HtK5okA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XxVpAX1j_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_rrKfULrt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Riy2AEtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_wFvqfChy, 0, m, &cVar_wFvqfChy_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_o2AKfTjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6BQRYsCP_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_DZeZNVK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7JQv1du6, 0, m, &cVar_7JQv1du6_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_sQXIvQXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_85OjOAZt_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_zYNWgLqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_azc80sQj, 0, m, &cVar_azc80sQj_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Unwajoxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2ivQmAM7, 0, m, &cVar_2ivQmAM7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rAHckH8I, 0, m, &cVar_rAHckH8I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SplAAonJ, 0, m, &cVar_SplAAonJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pvXWuLGm, 0, m, &cVar_pvXWuLGm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8E3LIhgM, 0, m, &cVar_8E3LIhgM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_00zUYIUP, 0, m, &cVar_00zUYIUP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_guqXgR6Z, 0, m, &cVar_guqXgR6Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hV1NkMqv, 0, m, &cVar_hV1NkMqv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uXEJR3Fd, 0, m, &cVar_uXEJR3Fd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lJK50tUt, 0, m, &cVar_lJK50tUt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ypo3mK9Z, 0, m, &cVar_Ypo3mK9Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QznjXeA5, 0, m, &cVar_QznjXeA5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4gXbGdu2_sendMessage);
  cMsg_mj2X4sCR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_xyfKsSS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rhBqkRAo, 0, m, &cVar_rhBqkRAo_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_VbSxYKvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_762OaX1y, 0, m, &cVar_762OaX1y_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_xczmOinX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CXnXLxuk, 0, m, &cVar_CXnXLxuk_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_kh742vqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uCZYmwuY, 0, m, &cVar_uCZYmwuY_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_uiYdpQlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wXB3ObEs, 0, m, &cVar_wXB3ObEs_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_YznSQQJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Io1tSZpc_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_cu8P33fD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XTl26tdk_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yyeATnWF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3UXf5GzU_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_mrcpqqza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_prKJJX3W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kz64Mzjq_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Dnr253R3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lL78mAUN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_rlvSHxsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yVWmBeJz, 0, m, &cVar_yVWmBeJz_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_tU8MIyiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s49tb9Gz, 0, m, &cVar_s49tb9Gz_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_1kXLOZrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Psa86rZn_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_dUFjtQ3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FOMLuUyd_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NwUxXTjI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EgCMiQMC_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_PQMSY6Ek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_evE5ndeQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xZLFAYmZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_5NCmHojW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TJ6WsnTI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_5dIlDU5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wFvqfChy, 0, m, &cVar_wFvqfChy_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_BHWeCGZe, VIf(I0));
    __hv_varread_f(&sVarf_BoUtqCEr, VOf(Bf0));
    __hv_varread_f(&sVarf_CylrREDA, VOf(Bf1));
    __hv_varread_f(&sVarf_vNONVIya, VOf(Bf2));
    __hv_varread_f(&sVarf_hYpfVyV6, VOf(Bf3));
    __hv_varread_f(&sVarf_wtJLH7pl, VOf(Bf4));
    __hv_varread_f(&sVarf_5ghGu2Gw, VOf(Bf5));
    __hv_varread_f(&sVarf_NkW9wt3g, VOf(Bf6));
    __hv_varwrite_f(&sVarf_BgyxzY6l, VIf(I0));
    __hv_varread_f(&sVarf_JjTZtcMe, VOf(Bf7));
    __hv_line_f(&sLine_OdYFE2ZW, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Rtjp5K7U, VOf(Bf9));
    __hv_line_f(&sLine_qTLFMXVu, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_L1IxDtji, VOf(Bf8));
    __hv_line_f(&sLine_xyZqn2W8, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_hYpfVyV6, VIf(Bf11));
    __hv_varread_f(&sVarf_BgyxzY6l, VOf(Bf11));
    __hv_line_f(&sLine_FJWQXHBA, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_ePaHBDLc, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_xRHeOaag, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_wtJLH7pl, VIf(Bf10));
    __hv_line_f(&sLine_MyhzOjSR, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_1RseGAD7, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_rbdDuGwt, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_5ghGu2Gw, VIf(Bf10));
    __hv_line_f(&sLine_9OuW3cUm, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_57HKroR8, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_aPlGpQMT, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_NkW9wt3g, VIf(Bf10));
    __hv_varwrite_f(&sVarf_JjTZtcMe, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Rtjp5K7U, VIf(Bf1));
    __hv_varwrite_f(&sVarf_L1IxDtji, VIf(Bf2));
    sEnv_process(this, &sEnv_e56GlJo6, VIf(Bf3), &sEnv_e56GlJo6_sendMessage);
    sEnv_process(this, &sEnv_VwAPW3Gb, VIf(I0), &sEnv_VwAPW3Gb_sendMessage);
    __hv_line_f(&sLine_3xVt32ck, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_wCTiz1Db, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_yZs5VTQ2, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_jX4bZ4ri, VOf(Bf3));
    __hv_line_f(&sLine_2DDJ0GpH, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_BoUtqCEr, VIf(Bf0));
    __hv_varwrite_f(&sVarf_jX4bZ4ri, VIf(Bf4));
    __hv_varwrite_f(&sVarf_0oSk3EKJ, VIf(Bf5));
    __hv_varwrite_f(&sVarf_6X0iqXCc, VIf(Bf6));
    __hv_varread_f(&sVarf_6X0iqXCc, VOf(Bf6));
    __hv_line_f(&sLine_Sjp13NYU, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_vNONVIya, VIf(Bf4));
    __hv_varread_f(&sVarf_0oSk3EKJ, VOf(Bf4));
    __hv_line_f(&sLine_YOW7NTXU, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_CylrREDA, VIf(Bf4));
    __hv_varwrite_f(&sVarf_5ID3hE9v, VIf(Bf2));
    __hv_varwrite_f(&sVarf_eZAttdqz, VIf(I1));
    __hv_varread_f(&sVarf_bvJmftTU, VOf(Bf2));
    __hv_varread_f(&sVarf_wFwG0Gpc, VOf(Bf4));
    __hv_varread_f(&sVarf_flBSwLZ2, VOf(Bf0));
    __hv_varread_f(&sVarf_sGJ5QU99, VOf(Bf5));
    __hv_varread_f(&sVarf_YiGFjNtA, VOf(Bf3));
    __hv_varread_f(&sVarf_o0f20ZFx, VOf(Bf6));
    __hv_varread_f(&sVarf_I074eljB, VOf(Bf1));
    __hv_varwrite_f(&sVarf_FciMrh7A, VIf(I1));
    __hv_varread_f(&sVarf_Enpvvzf7, VOf(Bf10));
    __hv_line_f(&sLine_M9LF4GkO, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_ESi2m6xQ, VOf(Bf7));
    __hv_line_f(&sLine_CvFWf12E, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_vtKKzz0H, VOf(Bf11));
    __hv_line_f(&sLine_eqN7Yqcq, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_sGJ5QU99, VIf(Bf12));
    __hv_varread_f(&sVarf_FciMrh7A, VOf(Bf12));
    __hv_line_f(&sLine_m7akqlsg, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_z9c8XSaw, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_1OofMhc1, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_YiGFjNtA, VIf(Bf9));
    __hv_line_f(&sLine_xvMFJyO9, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_FHfZU0Ie, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_IKjIYLLV, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_o0f20ZFx, VIf(Bf9));
    __hv_line_f(&sLine_tlKVhyUf, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_JKzjIAoE, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_I47n6Mnz, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_I074eljB, VIf(Bf9));
    __hv_varwrite_f(&sVarf_Enpvvzf7, VIf(Bf2));
    __hv_varwrite_f(&sVarf_ESi2m6xQ, VIf(Bf4));
    __hv_varwrite_f(&sVarf_vtKKzz0H, VIf(Bf0));
    sEnv_process(this, &sEnv_ahZGbell, VIf(Bf5), &sEnv_ahZGbell_sendMessage);
    sEnv_process(this, &sEnv_3kPndpho, VIf(I1), &sEnv_3kPndpho_sendMessage);
    __hv_line_f(&sLine_XiS8VxwN, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_YuJNbGwd, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_lrgaZmrA, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_7md44nbT, VOf(Bf5));
    __hv_line_f(&sLine_LyMURubq, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_bvJmftTU, VIf(Bf2));
    __hv_varwrite_f(&sVarf_7md44nbT, VIf(Bf3));
    __hv_varwrite_f(&sVarf_0Tz0YEm5, VIf(Bf6));
    __hv_varwrite_f(&sVarf_Sd6bzTq9, VIf(Bf1));
    __hv_varread_f(&sVarf_Sd6bzTq9, VOf(Bf1));
    __hv_line_f(&sLine_eouQKh8m, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_flBSwLZ2, VIf(Bf3));
    __hv_varread_f(&sVarf_0Tz0YEm5, VOf(Bf3));
    __hv_line_f(&sLine_iP6Swx8R, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_wFwG0Gpc, VIf(Bf3));
    __hv_varwrite_f(&sVarf_983xkA5g, VIf(Bf0));
    __hv_varread_f(&sVarf_eZAttdqz, VOf(Bf0));
    __hv_line_f(&sLine_NdFvMSEr, VOf(Bf3));
    __hv_varread_f(&sVarf_983xkA5g, VOf(Bf2));
    __hv_line_f(&sLine_lbMpUuxD, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_BHWeCGZe, VOf(Bf2));
    __hv_varread_f(&sVarf_5ID3hE9v, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
